#
# spec file for package python-XlsxWriter
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define         oldpython python
Name:           python-XlsxWriter
Version:        3.0.3
Release:        2.1
Summary:        Python module for writing OOXML spreadsheet files
License:        BSD-2-Clause
Group:          Development/Languages/Python
URL:            https://github.com/jmcnamara/XlsxWriter
Source:         https://github.com/jmcnamara/XlsxWriter/archive/RELEASE_%{version}.tar.gz#/XlsxWriter-RELEASE_%{version}.tar.gz
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires(post): update-alternatives
Requires(postun):update-alternatives
Provides:       python3-xlsxwriter = %{version}
Obsoletes:      python3-xlsxwriter < %{version}
BuildArch:      noarch
%ifpython2
# python-xlsxwriter was last used in openSUSE Leap 42.1.
Provides:       %{oldpython}-xlsxwriter = %{version}
Obsoletes:      %{oldpython}-xlsxwriter < %{version}
%endif
%python_subpackages

%description
XlsxWriter is a Python module for writing files in the Microsoft
Office Open XML spreadsheet format. It can be used to write text,
numbers, formulas and hyperlinks to multiple worksheets and it
supports features such as formatting and many more.

%prep
%setup -q -n XlsxWriter-RELEASE_%{version}

%build
%python_build

%install
%{python_expand #
%{$python_install}
mv %{buildroot}%{_bindir}/vba_extract.py \
   %{buildroot}%{_bindir}/vba_extract-%{$python_bin_suffix}
}

%python_expand %fdupes %{buildroot}%{$python_sitelib}
%prepare_alternative vba_extract

%post
%python_install_alternative vba_extract

%postun
%python_uninstall_alternative vba_extract

%check
%pytest

%files %{python_files}
%doc Changes README.rst
%license LICENSE.txt
%python_alternative %{_bindir}/vba_extract
%{python_sitelib}/xlsxwriter/
%{python_sitelib}/XlsxWriter-%{version}-py*.egg-info

%changelog
* Tue Oct 17 2023 Daniel Garcia Moreno <daniel.garcia@suse.com>
- Split the call to %%python_install in different lines to do not feed
  other commands as possible macro options.
* Mon Sep 26 2022 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright year
- update to version 3.0.3:
  * Added :func:`print_black_and_white` worksheet method to set "Black
    and White" print options.
- changes from version 3.0.2:
  * Added :func:`set_top_left_cell` worksheet method to position the
    first visible cell in a worksheet.
- changes from version 3.0.1:
  * Add python_requires version to setup.py to help pip find the
    correct matching version for Python 2 and 3.
- changes from version 3.0.0:
  * This is the first Python 3 only version of XlsxWriter. It is
    approximately 10-15%% faster than the Python2/3 version.  Python 2
    users should use XlsxWriter version 2.0.0, see below.
- changes from version 2.0.0:
  * This is the last XlsxWriter release to support Python 2. From now
    bug fixes and new features will only be available for Python
    3. The deprecation notice for Python 2 support in XlsxWriter has
    been in place since May 2020 and the Python community support for
    Python 2 ended in January 2020. Downloads of XlsxWriter for Python
    2 is currently less than 6%% of all downloads of the library, and
    decreasing month by month.  Python 2 users should still be able to
    install versions of XlsxWriter up to this release but not any
    releases afterwards.
- changes from version 1.4.5:
  * Added Description/Alt Text and Decorative accessibility options
    for charts, textboxes and buttons. These options were already
    available for images.
- changes from version 1.4.4:
  * Added some performance improvements. Performance for larger files
    should be 5-10%% better.
- changes from version 1.4.3:
  * Added support for background images in worksheets. See
    :func:`set_background` and :ref:`ex_background`.
- changes from version 1.4.2 :
  * Added support for GIF image files (and in Excel 365, animated GIF
    files).
- changes from version 1.4.1:
  * Added support for dynamic arrays and new Excel 365 functions like
    UNIQUE and FILTER. See :func:`write_dynamic_array_formula`,
    :ref:`formula_dynamic_arrays` and :ref:`ex_dynamic_arrays`.
  * Added constructor option "use_future_functions" to enable newer
    Excel "future" functions in Formulas. See :ref:`formula_future`,
    and the :func:`Workbook` constructor.
- changes from version 1.4.0:
  * Added fix for issue for where a y_axis font rotation of 0 was
    ignored.
- changes from version 1.3.9 :
  * Added option to set row heights and column widths in pixels via
    the :func:`set_row_pixels` and :func:`set_column_pixels` methods.
- changes from version 1.3.8 :
  * Added ability to add accessibility options "description" and
    "decorative" to images via :func:`insert_image`. :feature:`768`.
  * Added fix for datetime.timedelta values that exceed the Excel 1900
    leap day (timedeltas greater than 59 days, in hours). This is a
    backward incompatible change. :issue:`731`.
  * Added the worksheet :func:`read_only_recommended` method to set
    the Excel "Read-only Recommended" option that is available when
    saving a file.  :feature:`784`.
  * Fixed issue where temp files used in `constant_memory` mode
    weren't closed/deleted if the workbook object was garbage
    collected. :issue:`764`.
  * Fixed issue where pattern formats without colors were given a
    default black fill color. :issue:`790`.
  * Added option to set a chart crossing to 'min' as well as the
    existing 'max' option. The 'min' option isn't available in the
    Excel interface but can be enabled via VBA. :feature:`773`.
* Mon Feb  8 2021 Markéta Machová <mmachova@suse.com>
- %%ifpython3 does not work with multi-build python
* Tue Nov 10 2020 Marketa Calabkova <mmachova@suse.com>
- Update to 1.3.7
  * Added support for chart custom data labels
  * Added Border, Fill, Pattern and Gradient formatting to chart data labels and
    chart custom data labels.
  * Replaced internal MD5 digest used to check for duplicate images with a SHA256
    digest to avoid issues on operating systems such as Red Hat in FIPS mode
    which don't support MD5 for security reasons.
  * Added check, and warning, for worksheet tables with no data row.
    Either with or without a header row.
  * Added text alignment for textboxes. The existing options allowed the text
    area to be aligned but didn't offer control over the text within that area.
* Wed Jun 24 2020 Todd R <toddrme2178@gmail.com>
- Update to Release 1.2.9
  * Added support for ``stacked`` and ``percent_stacked`` Line charts.
- Update to Release 1.2.8
  * Fix for issue where duplicate images with hyperlinks weren't handled
    correctly.
    Issue `#686 <https://github.com/jmcnamara/XlsxWriter/issues/686>`_.
  * Removed ``ReservedWorksheetName`` exception which was used with the reserved
    worksheet name "History" since this name is allowed in some Excel variants.
    Issue `#688 <https://github.com/jmcnamara/XlsxWriter/issues/688>`_.
  * Fix for worksheet objects (charts, images and textboxes) that are inserted
    with an offset that starts in a hidden cell.
    Issue `#676 <https://github.com/jmcnamara/XlsxWriter/issues/676>`_.
  * Fix to allow handling of NoneType in :func:`add_write_handler`.
    Issue `#677 <https://github.com/jmcnamara/XlsxWriter/issues/677>`_.
* Thu Jan 30 2020 Todd R <toddrme2178@gmail.com>
- Update to version 1.2.7
  * Fix for duplicate images being copied to an XlsxWriter file. Excel uses an
    optimization where it only stores one copy of a repeated/duplicate image in
    a workbook. XlsxWriter didn't do this which meant that the file size would
    increase when then was a large number of repeated images. This release fixes
    that issue and replicates Excel's behavior.
  * Added documentation on :ref:`num_format_categories` and
    :ref:`num_format_locale`.
  * Added note to :func:`protect()` about how it is possible to encrypt an
    XlsxWriter file using a third party, cross platform, open source tool called
    `msoffice-crypt <https://github.com/herumi/msoffice>`_.
- Update to version 1.2.6
  * Added option to remove style from worksheet tables.
- Update to version 1.2.5
  * Added option to add hyperlinks to textboxes. See :ref:`textbox_hyperlink`.
- Update to version 1.2.4
  * Added option to link textbox text from a cell. See :ref:`textbox_textlink`.
  * Added option to rotate text in a textbox. See
    :ref:`textbox_formatting_rotation`.
- Update to version 1.2.3
  * Increased allowable worksheet url length from 255 to 2079 characters, as
    supported in more recent versions of Excel. A lower or user defined limit
    can be set via the ``max_url_length`` property in the :func:`Workbook`
    constructor.
  * Fixed several issues with hyperlinks in worksheet images.
- Update to version 1.2.2
  * Fixed Python 3.8.0 warnings.
- Update to version 1.2.1
  * Added the :func:`add_write_handler` method to allow user defined types to be
    handled by the :func:`write` method. See :ref:`writing_user_types` for more
    information.
  * Add support for East Asian vertical fonts in charts.
- Update to version 1.2.0
  * Refactored exception handling around the workbook file :func:`close()`
    method to allow exceptions to be caught and handled. See
    :ref:`ex_check_close`. Also refactored the code to clean up temp files in
    the event of an exception.
  * Added the option to allow chart fonts to be rotated to 270 degrees
    to give a stacked orientation. See :ref:`chart_fonts`.
- Update to version 1.1.9
  * Another fix for issues where zipfile.py raises "ZIP does not support
    timestamps before 1980" exception.
* Sat Sep 14 2019 John Vandenberg <jayvdb@gmail.com>
- Use %%pytest, as setup.py test invokes python which does not exist
  if only python3 flavour is built.
* Mon Jul 22 2019 Todd R <toddrme2178@gmail.com>
- Update to Release 1.1.8
  * Added ability to combine Doughnut and Pie charts.
  * Added gauge chart example which is a combination of a Doughnut and a Pie
    chart.
- Update to Release 1.1.7
  * Added docs on object_position.
  * Added fix for sizing of cell comment boxes when they cross columns/rows that
    have size changes that occur after the comment is written.
  * Added fix for the sizing of worksheet objects (images, charts, textboxes)
    when the underlying cell sizes have changed and the "object_position"
    parameter has been set to 1 "Move and size with cells". An additional mode 4
    has been added to simulate inserting the object in hidden rows.
  * Added object positioning for charts and textboxes, it was already supported
    for images. Note, the parameter is now called ``object_position``. The
    previous parameter name ``positioning`` is deprecated but still supported
    for images.
- Update to Release 1.1.6
  * Fixed issue where images that started in hidden rows/columns weren't placed
    correctly in the worksheet.
  * Fixed the mime-type reported by system ``file(1)``. The mime-type reported
    by "file --mime-type"/magic was incorrect for XlsxWriter files since it
    expected the ``[Content_types]`` to be the first file in the zip container.
* Mon Feb 25 2019 John Vandenberg <jayvdb@gmail.com>
- Update to v1.1.5
  * Break compatibility with Python 2.6
* Fri Feb 22 2019 John Vandenberg <jayvdb@gmail.com>
- Update to v1.1.4
  * Fix for issues where zipfile.py raises "ZIP does not support
    timestamps before 1980" exception.
    Issue `#535 <https://github.com/jmcnamara/XlsxWriter/issues/535>`_.
- from v1.1.3
  * Fix handling of ``'num_format': '0'`` in duplicate formats.
    Issue `#584 <https://github.com/jmcnamara/XlsxWriter/issues/584>`_.
- Activate the test suite using the GitHub repository archive.
* Sat Dec 22 2018 Todd R <toddrme2178@gmail.com>
- Update to version 1.1.2
  * Fix for issue where ``in_memory`` files weren't compressed.
    Issue `#573 <https://github.com/jmcnamara/XlsxWriter/issues/573>`_.
  * Fix ``write()`` so that it handles array formulas as documented.
    Issue `#418 <https://github.com/jmcnamara/XlsxWriter/issues/418>`_.
  * Fix for issue with special characters in worksheet table functions.
    Issue `#442 <https://github.com/jmcnamara/XlsxWriter/issues/442>`_.
  * Added warnings for input issues in :func:`write_rich_string()` such as blank
    strings, double formats or insufficient parameters.
    Issue `#425 <https://github.com/jmcnamara/XlsxWriter/issues/425>`_.
- Update to version 1.1.1
  * Added comment font name and size options.
    Issue `#201 <https://github.com/jmcnamara/XlsxWriter/issues/201>`_.
  * Fix for issue when using text boxes in the same workbook as a chartsheet.
    Issue `#420 <https://github.com/jmcnamara/XlsxWriter/issues/420>`_.
- Update to version 1.1.0
  * Added functionality to align chart category axis labels. See the
    ``label_align`` property of the :func:`set_x_axis()` method.
  * Added worksheet :func:`hide_row_col_headers()` method to turn off worksheet
    row and column headings.
    Issue `#480 <https://github.com/jmcnamara/XlsxWriter/issues/480>`_.
  * Added the :func:`set_tab_ratio()` method to set the ratio between the
    worksheet tabs and the horizontal slider.
    Issue `#481 <https://github.com/jmcnamara/XlsxWriter/issues/481>`_.
  * Fixed issue with icon conditional formats when the values were zero.
    Issue `#565 <https://github.com/jmcnamara/XlsxWriter/issues/565>`_.
- Update to version 1.0.9
  * Fix for issue with formulas quoted as strings in conditional formats,
    introduced in version 1.0.7.
    Issue `#564 <https://github.com/jmcnamara/XlsxWriter/issues/564>`_.
- Update to version 1.0.8
  * Added named exceptions to XlsxWriter. See :ref:`exceptions`.
  * Removed the implicit :func:`close()` in the destructor since it wasn't
    guaranteed to work correctly and raised a confusing exception when any other
    exception was triggered. **Note that this is a backward incompatible
    change.** The ``with`` context manager is a better way to close
    automatically, see :func:`close()`.
  * Added border, fill, pattern and gradient formatting options to
    :func:`set_legend()`.
    Issue `#545 <https://github.com/jmcnamara/XlsxWriter/issues/545>`_.
  * Added ``top_right`` position to :func:`set_legend()`.
    Issue `#537 <https://github.com/jmcnamara/XlsxWriter/issues/537>`_.
- Update to version 1.0.7
  * Fix for unicode type error in Python 3.
    Issue `#554 <https://github.com/jmcnamara/XlsxWriter/issues/554>`_.
- Update to version 1.0.6
  * Added some performance improvements.
    PR `#551 <https://github.com/jmcnamara/XlsxWriter/pull/551>`_.
- Update to version 1.0.5
  * Added example of how to subclass the Workbook and Worksheet objects. See
    :ref:`ex_inheritance1` and :ref:`ex_inheritance2`.
  * Added support for WMF and EMF image formats to the Worksheet
    :func:`add_image` method.
- Update to version 1.0.4
  * Set the xlsx internal file member datetimes to 1980-01-01 00:00:00 like
    Excel so that apps can produce a consistent binary file once the workbook
    :func:`set_properties` ``created`` date is set.
    Pull request `#495 <https://github.com/jmcnamara/XlsxWriter/pull/495>`_.
  * Fix for jpeg images that reported unknown height/width due to unusual SOF markers.
    Issue `#506 <https://github.com/jmcnamara/XlsxWriter/issues/506>`_.
  * Added support for blanks in list autofilter.
    Issue `#505 <https://github.com/jmcnamara/XlsxWriter/issues/505>`_.
- Update to version 1.0.3
  * Added Excel 2010 data bar features such as solid fills and control over the
    display of negative values. See :ref:`working_with_conditional_formats` and
    :ref:`ex_cond_format`.
    Feature request `#502 <https://github.com/jmcnamara/XlsxWriter/issues/502>`_.
  * Fixed :func:`set_column` parameter names to match docs and other methods.
    Note, this is a backward incompatible change.
    Issue `#504 <https://github.com/jmcnamara/XlsxWriter/issues/504>`_.
  * Fixed missing plotarea formatting in pie/doughnut charts.
- Update to version 1.0.2
  * Fix for cases where the hyperlink style added in the previous release didn't
    work.
    Feature request `#455 <https://github.com/jmcnamara/XlsxWriter/issues/455>`_.
- Update to version 1.0.1
  * Changed default :func:`write_url` format to the Excel hyperlink style so that
    it changes when the theme is changed and also so that it indicates that the
    link has been clicked.
    Feature request `#455 <https://github.com/jmcnamara/XlsxWriter/issues/455>`_.
- Update to version 1.0.0
  * Added icon sets to conditional formatting. See
    :ref:`working_with_conditional_formats` and :ref:`ex_cond_format`.
    Feature request `#387 <https://github.com/jmcnamara/XlsxWriter/issues/387>`_.
- Update to version 0.9.9
  * Added ``stop_if_true`` parameter to conditional formatting.
    Feature request `#386 <https://github.com/jmcnamara/XlsxWriter/issues/386>`_.
- Update to version 0.9.8
  * Fixed issue where spurious deprecation warning was raised in ``-Werror`` mode.
    ssue `#451 <https://github.com/jmcnamara/XlsxWriter/issues/451>`_.
- Update to version 0.9.7
  * Minor bug and doc fixes.
* Thu Mar  2 2017 sor.alexei@meowr.ru
- Update to version 0.9.6 (changes since 0.9.3):
  * Add user definable removal of timezones in datetimes
    (gh#jmcnamara/XlsxWriter#257).
  * Fix a duplicate header warning in add_table when there is only
    one user defined header (gh#jmcnamara/XlsxWriter#380).
  * A fix for the center_across property in add_format
    (gh#jmcnamara/XlsxWriter#381).
  * A fix for a missing remove_timezone option in the Chart class
    (gh#jmcnamara/XlsxWriter#404).
  * A fix for a table with data but without a header
    (gh#jmcnamara/XlsxWriter#405>).
  * Add a warning when the number of series in a chart exceeds
    Excel's limit of 255 (gh#jmcnamara/XlsxWriter#399).
- Update for the multipython build.
* Mon Aug 15 2016 toddrme2178@gmail.com
- Fix update-alternatives implementation.
* Fri Jul 22 2016 sor.alexei@meowr.ru
- Update to version 0.9.3 (changes since 0.8.7):
  * Add workbook :func:`set_custom_property` method to set custom
    document properties.
  * Fix for :func:`insert_image` issue when handling images with
    zero dpi.
  * Add :ref:`trendline properties <chart_series_option_trendline>`:
  ``intercept``, ``display_equation`` and ``display_r_squared``.
  * Documented used of font rotation in chart :ref:`data labels
    <chart_series_option_data_labels>`.
  * Add workbook :func:`set_size` method to set the workbook window
    size.
  * Add check to :func:`add_table` to prevent duplicate header
    names which leads to a corrupt Excel file.
- Fix SLE 11 build.
* Wed May 25 2016 toddrme2178@gmail.com
- Update to 0.8.7
  * Fix for issue when inserting read-only images on Windows.
    Issue `#352 <https://github.com/jmcnamara/XlsxWriter/issues/352>`_.
  * Added :func:`get_worksheet_by_name()` method to allow the retrieval of a
    worksheet from a workbook via its name.
  * Fixed issue where internal file creation and modification dates where in the
    local timezone instead of UTC.
- Switch to pythonhosted URL.
- Rename to python3-XlsxWriter to conform to python packaging guidelines
- Implement update-alternatives
* Thu Apr 28 2016 sor.alexei@meowr.ru
- Update to version 0.8.6 (changes since 0.8.4):
  * Add additional documentation on :ref:`ewx_pandas` and
    :ref:`pandas_examples`.
  * Add fix for :func:`set_center_across` format method.
  * Fix for ``external:`` urls where the target/anchor contains
    spaces.
* Thu Feb 11 2016 sor.alexei@meowr.ru
- Update to 0.8.4 (changes since 0.7.7):
  * Add checks for valid and non-duplicate worksheet table names.
  * Add chart pattern fills, see :ref:`chart_formatting_pattern`
    and :ref:`ex_chart_pattern`.
  * Add additional documentation on :ref:`working_with_formulas`.
  * Add option to set chart tick interval.
  * Add transparency option to solid fill colours in chart areas
    (:ref:`chart_formatting_fill`).
  * Add options to configure chart axis tick placement.
    See :func:`set_x_axis()`.
  * Fix for :func:`write_url` exception when the URL contains two
    ``#`` location/anchors. Note, URLs like this aren't strictly
    valid and cannot be entered manually in Excel.
* Mon Nov 23 2015 sor.alexei@meowr.ru
- Update to 0.7.7:
  * Add support for table header formatting and a fix for wrapped
    lines in the header.
* Sat Oct 10 2015 sor.alexei@meowr.ru
- Update to 0.7.6:
  * Add option to allow data validation input messages with the
    'any' validate parameter.
  * Fix url encoding of links to external files and directories.
  * Allow hyperlinks longer than 255 characters when the link and
    anchor are each less than or equal to 255 characters.
  * Add ``hyperlink_base`` document property.
  * Fix for images with negative offsets.
* Sat Jul 18 2015 sor.alexei@meowr.ru
- Initial package.
